( cd usr/share/doc/HTML/en/guarddog ; rm -rf common )
( cd usr/share/doc/HTML/en/guarddog ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/es/guarddog ; rm -rf common )
( cd usr/share/doc/HTML/es/guarddog ; ln -sf /usr/share/doc/HTML/es/common common )
